@@ -7,7 +7,6 @@ from fractions import Fraction
 import numpy as np
 from monty.design_patterns import cached_class
 
-
 import textwrap
 
 from pymatgen.core import Lattice
@@ -29,6 +28,7 @@ __date__ = "Feb 2017"
 
 MAGSYMM_DATA = os.path.join(os.path.dirname(__file__), "symm_data_magnetic.sqlite")
 
+
 @cached_class
 class MagneticSpaceGroup(SymmetryGroup):
 
@@ -39,7 +39,7 @@ class MagneticSpaceGroup(SymmetryGroup):
         as a string. To create a magnetic structure in pymatgen, the
         Structure.from_magnetic_spacegroup() method can be used, which
         relies on this class.
-        
+
         The main difference between magnetic space groups and normal
         crystallographic space groups is the inclusion of a time reversal
         operator that acts on an atom's magnetic moment. This is
@@ -47,11 +47,11 @@ class MagneticSpaceGroup(SymmetryGroup):
         operation in its label, e.g. the standard crystallographic
         space group Pnma has magnetic subgroups Pn'ma, Pnm'a, Pnma',
         Pn'm'a, Pnm'a', Pn'ma', Pn'm'a'.
-        
+
         The magnetic space groups are classified as one of 4 types
         where G = magnetic space group, and F = parent crystallographic
         space group:
-        
+
         1.  G=F no time reversal, i.e. the same as corresponding
             crystallographic group
         2.  G=F+F1', "grey" groups, where avg. magnetic moment is zero,
@@ -59,13 +59,13 @@ class MagneticSpaceGroup(SymmetryGroup):
         3.  G=D+(F-D)1', where D is an equi-translation subgroup of F of
             index 2, lattice translations do not include time reversal
         4.  G=D+(F-D)1', where D is an equi-class subgroup of F of index 2
-        
+
         There are two common settings for magnetic space groups, BNS
         and OG. In case 4, the BNS setting != OG setting, and so a
         transformation to go between the two settings is required:
         specifically, the BNS setting is derived from D, and the OG
         setting is derived from F.
-        
+
         This means that the OG setting refers to the unit cell if magnetic
         order is neglected, and requires multiple unit cells to reproduce
         the full crystal periodicity when magnetic moments are present.
@@ -73,11 +73,11 @@ class MagneticSpaceGroup(SymmetryGroup):
         electronic structure calculations and the BNS setting is preferred.
         However, this class does contain information on the OG setting and
         can be initialized from OG labels or numbers if required.
-        
+
         Conventions: ITC monoclinic unique axis b, monoclinic cell choice 1,
         hexagonal axis for trigonal groups, origin choice 2 for groups with
         more than one origin choice (ISO-MAG).
-        
+
         Raw data comes from ISO-MAG, ISOTROPY Software Suite, iso.byu.edu
         http://stokes.byu.edu/iso/magnetic_data.txt
         with kind permission from Professor Branton Campbell, BYU
@@ -87,10 +87,10 @@ class MagneticSpaceGroup(SymmetryGroup):
             of Crystallography, 2013) www.iucr.org/publ/978-0-9553602-2-0.
         (2) C. J. Bradley and A. P. Cracknell, The Mathematical Theory of
             Symmetry in Solids (Clarendon Press, Oxford, 1972).
-        
+
         See http://stokes.byu.edu/iso/magneticspacegroupshelp.php for more
         information on magnetic symmetry.
-        
+
         :param id: BNS number supplied as list of 2 ints or BNS label as
             str or index as int (1-1651) to iterate over all space groups"""
 
@@ -108,12 +108,12 @@ class MagneticSpaceGroup(SymmetryGroup):
         c = db.cursor()
         if isinstance(id, str):
             id = "".join(id.split())  # remove any white space
-            c.execute('SELECT * FROM space_groups WHERE BNS_label=?;', (id, ))
+            c.execute('SELECT * FROM space_groups WHERE BNS_label=?;', (id,))
         elif isinstance(id, list):
             c.execute('SELECT * FROM space_groups WHERE BNS1=? AND BNS2=?;', (id[0], id[1]))
         elif isinstance(id, int):
             # OG3 index is a 'master' index, going from 1 to 1651
-            c.execute('SELECT * FROM space_groups WHERE OG3=?;', (id, ))
+            c.execute('SELECT * FROM space_groups WHERE OG3=?;', (id,))
         raw_data = list(c.fetchone())
 
         self._data['magtype'] = raw_data[0]  # int from 1 to 4
@@ -125,7 +125,7 @@ class MagneticSpaceGroup(SymmetryGroup):
         def _get_point_operator(idx):
             '''Retrieve information on point operator (rotation matrix and Seitz label).'''
             hex = self._data['bns_number'][0] >= 143 and self._data['bns_number'][0] <= 194
-            c.execute('SELECT symbol, matrix FROM point_operators WHERE idx=? AND hex=?;', (idx-1, hex))
+            c.execute('SELECT symbol, matrix FROM point_operators WHERE idx=? AND hex=?;', (idx - 1, hex))
             op = c.fetchone()
             op = {'symbol': op[0], 'matrix': np.array(op[1].split(','), dtype='f').reshape(3, 3)}
             return op
@@ -134,13 +134,13 @@ class MagneticSpaceGroup(SymmetryGroup):
             '''Parses compact binary representation into list of MagSymmOps.'''
             if len(b) == 0:  # e.g. if magtype != 4, OG setting == BNS setting, and b == [] for OG symmops
                 return None
-            raw_symops = [b[i:i+6] for i in range(0, len(b), 6)]
+            raw_symops = [b[i:i + 6] for i in range(0, len(b), 6)]
 
             symops = []
 
             for r in raw_symops:
                 point_operator = _get_point_operator(r[0])
-                translation_vec = [r[1]/r[4], r[2]/r[4], r[3]/r[4]]
+                translation_vec = [r[1] / r[4], r[2] / r[4], r[3] / r[4]]
                 time_reversal = r[5]
                 op = MagSymmOp.from_rotation_and_translation_and_time_reversal(rotation_matrix=point_operator['matrix'],
                                                                                translation_vec=translation_vec,
@@ -165,7 +165,7 @@ class MagneticSpaceGroup(SymmetryGroup):
 
             def get_label(idx):
                 if idx <= 25:
-                    return chr(97+idx)  # returns a-z when idx 0-25
+                    return chr(97 + idx)  # returns a-z when idx 0-25
                 else:
                     return 'alpha'  # when a-z labels exhausted, use alpha, only relevant for a few space groups
 
@@ -173,12 +173,12 @@ class MagneticSpaceGroup(SymmetryGroup):
             n = 1  # nth Wyckoff site
             num_wyckoff = b[0]
             while len(wyckoff_sites) < num_wyckoff:
-                m = b[1+o]  # multiplicity
-                label = str(b[2+o]*m)+get_label(num_wyckoff-n)
+                m = b[1 + o]  # multiplicity
+                label = str(b[2 + o] * m) + get_label(num_wyckoff - n)
                 sites = []
                 for j in range(m):
-                    s = b[3+o+(j*22):3+o+(j*22)+22]  # data corresponding to specific Wyckoff position
-                    translation_vec = [s[0]/s[3], s[1]/s[3], s[2]/s[3]]
+                    s = b[3 + o + (j * 22):3 + o + (j * 22) + 22]  # data corresponding to specific Wyckoff position
+                    translation_vec = [s[0] / s[3], s[1] / s[3], s[2] / s[3]]
                     matrix = [[s[4], s[7], s[10]],
                               [s[5], s[8], s[11]],
                               [s[6], s[9], s[12]]]
@@ -198,7 +198,7 @@ class MagneticSpaceGroup(SymmetryGroup):
                 wyckoff_sites.append({'label': label,
                                       'str': ' '.join([s['str'] for s in sites])})
                 n += 1
-                o += m*22 + 2
+                o += m * 22 + 2
 
             return wyckoff_sites
 
@@ -206,15 +206,15 @@ class MagneticSpaceGroup(SymmetryGroup):
             '''Parses compact binary representation into list of lattice vectors/centerings.'''
             if len(b) == 0:
                 return None
-            raw_lattice = [b[i:i+4] for i in range(0, len(b), 4)]
+            raw_lattice = [b[i:i + 4] for i in range(0, len(b), 4)]
 
             lattice = []
 
             for r in raw_lattice:
-                lattice.append({'vector': [r[0]/r[3], r[1]/r[3], r[2]/r[3]],
-                                'str': '({0},{1},{2})+'.format(Fraction(r[0]/r[3]).limit_denominator(),
-                                                               Fraction(r[1]/r[3]).limit_denominator(),
-                                                               Fraction(r[2]/r[3]).limit_denominator())})
+                lattice.append({'vector': [r[0] / r[3], r[1] / r[3], r[2] / r[3]],
+                                'str': '({0},{1},{2})+'.format(Fraction(r[0] / r[3]).limit_denominator(),
+                                                               Fraction(r[1] / r[3]).limit_denominator(),
+                                                               Fraction(r[2] / r[3]).limit_denominator())})
 
             return lattice
 
@@ -227,7 +227,7 @@ class MagneticSpaceGroup(SymmetryGroup):
             P = [[b[0], b[3], b[6]],
                  [b[1], b[4], b[7]],
                  [b[2], b[5], b[8]]]
-            p = [b[9]/b[12], b[10]/b[12], b[11]/b[12]]
+            p = [b[9] / b[12], b[10] / b[12], b[11] / b[12]]
             P = np.array(P).transpose()
             P_string = transformation_to_string(P, components=('a', 'b', 'c'))
             p_string = "{},{},{}".format(Fraction(p[0]).limit_denominator(),
@@ -238,7 +238,7 @@ class MagneticSpaceGroup(SymmetryGroup):
         for i in range(8, 15):
             try:
                 raw_data[i] = array('b', raw_data[i])  # construct array from sql binary blobs
-            except:
+            except Exception:
                 # array() behavior changed, need to explicitly convert buffer to str in earlier Python
                 raw_data[i] = array('b', str(raw_data[i]))
 
@@ -256,16 +256,16 @@ class MagneticSpaceGroup(SymmetryGroup):
     def from_og(cls, id):
         """
         Initialize from Opechowski and Guccione (OG) label or number.
-        
+
         :param id: OG number supplied as list of 3 ints or
             or OG label as str
-        :return: 
+        :return:
         """
 
         db = sqlite3.connect(MAGSYMM_DATA)
         c = db.cursor()
         if isinstance(id, str):
-            c.execute('SELECT BNS_label FROM space_groups WHERE OG_label=?', (id, ))
+            c.execute('SELECT BNS_label FROM space_groups WHERE OG_label=?', (id,))
         elif isinstance(id, list):
             c.execute('SELECT BNS_label FROM space_groups WHERE OG1=? and OG2=? and OG3=?', (id[0], id[1], id[2]))
         bns_label = c.fetchone()[0]
@@ -321,7 +321,7 @@ class MagneticSpaceGroup(SymmetryGroup):
                                                                                        time_reversal=op.time_reversal)
                     centered_ops.append(new_op)
 
-        ops = ops+centered_ops
+        ops = ops + centered_ops
 
         return ops
 
@@ -331,7 +331,7 @@ class MagneticSpaceGroup(SymmetryGroup):
 
         Args:
             p: Point as a 3x1 array.
-            m: A magnetic moment, compatible with 
+            m: A magnetic moment, compatible with
             :class:`pymatgen.electronic_structure.core.Magmom`
             tol: Tolerance for determining if sites are the same. 1e-5 should
                 be sufficient for most purposes. Set to 0 for exact matching
@@ -373,20 +373,17 @@ class MagneticSpaceGroup(SymmetryGroup):
 
         if crys_system == "cubic":
             a = abc[0]
-            return check(abc, [a, a, a], tol) and\
-                check(angles, [90, 90, 90], angle_tol)
+            return check(abc, [a, a, a], tol) and check(angles, [90, 90, 90], angle_tol)
         elif crys_system == "hexagonal" or (crys_system == "trigonal" and
                                             self.symbol.endswith("H")):
             a = abc[0]
-            return check(abc, [a, a, None], tol)\
-                and check(angles, [90, 90, 120], angle_tol)
+            return check(abc, [a, a, None], tol) and check(angles, [90, 90, 120], angle_tol)
         elif crys_system == "trigonal":
             a = abc[0]
             return check(abc, [a, a, a], tol)
         elif crys_system == "tetragonal":
             a = abc[0]
-            return check(abc, [a, a, None], tol) and\
-                check(angles, [90, 90, 90], angle_tol)
+            return check(abc, [a, a, None], tol) and check(angles, [90, 90, 90], angle_tol)
         elif crys_system == "orthorhombic":
             return check(angles, [90, 90, 90], angle_tol)
         elif crys_system == "monoclinic":
@@ -418,10 +415,10 @@ class MagneticSpaceGroup(SymmetryGroup):
                                if len(self._data['bns_lattice']) > 3 else '')  # don't show (1,0,0)+ (0,1,0)+ (0,0,1)+
 
         desc['bns_wyckoff'] = '\n'.join([textwrap.fill(wyckoff_data['str'],
-                                                       initial_indent=wyckoff_data['label']+"  ",
-                                                       subsequent_indent=" " * len(wyckoff_data['label']+"  "),
+                                                       initial_indent=wyckoff_data['label'] + "  ",
+                                                       subsequent_indent=" " * len(wyckoff_data['label'] + "  "),
                                                        break_long_words=False, break_on_hyphens=False)
-                                        for wyckoff_data in self._data['bns_wyckoff']])
+                                         for wyckoff_data in self._data['bns_wyckoff']])
 
         desc['og_bns_transformation'] = ('OG-BNS Transform: ({})\n'.format(self._data['og_bns_transform'])
                                          if desc['magtype'] == 4 and include_og else '')
@@ -481,12 +478,13 @@ class MagneticSpaceGroup(SymmetryGroup):
         """
         return self.data_str(include_og=False)
 
+
 def _write_all_magnetic_space_groups_to_file(filename):
     """
     Write all magnetic space groups to a human-readable text file.
     Should contain same information as text files provided by ISO-MAG.
-    :param filename: 
-    :return: 
+    :param filename:
+    :return:
     """
     s = ('Data parsed from raw data from:\n'
          'ISO-MAG, ISOTROPY Software Suite, iso.byu.edu\n'
